@@ -40,18 +40,11 @@ SchemeEditorDialog::SchemeEditorDialog(const QString &path, QWidget *parent)
     , m_disableUpdates(false)
     , m_unsavedChanges(false)
 {
-    if (!path.isEmpty()) {
-        m_config = KSharedConfig::openConfig(path);
-    } else {
-        m_config = KSharedConfig::openConfig(QStringLiteral("kdeglobals"));
-        m_config->setReadDefaults(true);
-    }
+    m_config = KSharedConfig::openConfig(path);
     m_schemeName = KConfigGroup(m_config, "General").readEntry("Name");
 
     setupUi(this);
-    if (!path.isEmpty()) {
-        this->setWindowTitle(m_schemeName);
-    }
+    this->setWindowTitle(m_schemeName);
 
     schemeKnsUploadButton->setIcon( QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")) );
 
