@@ -24,12 +24,13 @@
 #include "FontInstInterface.h"
 #include "FontinstIface.h"
 #include "FontInst.h"
-#include <KDebug>
 #include <kio/global.h>
+#include <QDebug>
 #include <QtDBus/QDBusServiceWatcher>
 #include "config-fontinst.h"
+#include "debug.h"
 
-#define KFI_DBUG kDebug(7000) << '(' << time(NULL) << ')'
+#define KFI_DBUG qCDebug(KCM_KFONTINST_KIO) << '(' << time(NULL) << ')'
 
 namespace KFI
 {
