@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2013 Alexander Mezin <mezin.alexander@gmail.com>
+ * Copyright 2017 Roman Gilg <subdiff@gmail.com>
+ * Copyright 2013 Alexander Mezin <mezin.alexander@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,39 +21,46 @@
 #define TOUCHPADBACKEND_H
 
 #include <QObject>
+#include <QVector>
 #include <QVariantHash>
 
-//#include <kdemacros.h>
-
 class Q_DECL_EXPORT TouchpadBackend : public QObject
 {
     Q_OBJECT
 
 protected:
-	explicit TouchpadBackend(QObject *parent);
+        explicit TouchpadBackend(QObject *parent) : QObject(parent) {}
 
 public:
-
     static TouchpadBackend *implementation();
 
-    virtual bool applyConfig(const QVariantHash &) = 0;
-    virtual bool getConfig(QVariantHash &) = 0;
-    virtual QStringList supportedParameters() const = 0;
-    virtual const QString &errorString() const = 0;
+    virtual bool applyConfig(const QVariantHash &) {return false;}
+    virtual bool getConfig(QVariantHash &) {return false;}
+
+    virtual bool applyConfig() {return false;}
+    virtual bool getConfig() {return false;}
+    virtual bool getDefaultConfig() {return false;}
+    virtual bool isChangedConfig() const {return false;}
+
+    virtual QStringList supportedParameters() const {return QStringList();}
+    virtual const QString &errorString() const {return QString();}
+
+    virtual QVector<QObject*> getDevices() const { return QVector<QObject*>(); }
+    virtual int touchpadCount() const {return 0;}
 
     enum TouchpadOffState {
         TouchpadEnabled, TouchpadTapAndScrollDisabled, TouchpadFullyDisabled
     };
-    virtual void setTouchpadOff(TouchpadOffState) = 0;
-    virtual TouchpadOffState getTouchpadOff() = 0;
+    virtual void setTouchpadOff(TouchpadOffState) {}
+    virtual TouchpadOffState getTouchpadOff() {return TouchpadFullyDisabled;}
 
-    virtual bool isTouchpadAvailable() = 0;
-    virtual bool isTouchpadEnabled() = 0;
-    virtual void setTouchpadEnabled(bool) = 0;
+    virtual bool isTouchpadAvailable() {return false;}
+    virtual bool isTouchpadEnabled() {return false;}
+    virtual void setTouchpadEnabled(bool) {}
 
-    virtual QStringList listMouses(const QStringList &blacklist) = 0;
+    virtual void watchForEvents(bool keyboard) {}
 
-    virtual void watchForEvents(bool keyboard) = 0;
+    virtual QStringList listMouses(const QStringList &blacklist) {return QStringList();}
 
 Q_SIGNALS:
     void touchpadStateChanged();
@@ -60,6 +68,9 @@ Q_SIGNALS:
     void touchpadReset();
     void keyboardActivityStarted();
     void keyboardActivityFinished();
+
+    void touchpadAdded(bool success);
+    void touchpadRemoved(int index);
 };
 
 #endif // TOUCHPADBACKEND_H
